@@ -1,5 +1,5 @@
 package HackaMol;
-$HackaMol::VERSION = '0.051';
+$HackaMol::VERSION = '0.052';
 #ABSTRACT: HackaMol: Object-Oriented Library for Molecular Hacking
 use 5.008;
 use Moose;
@@ -16,10 +16,10 @@ use Scalar::Util qw(refaddr);
 use Carp;
 
 has 'readline_func' => (
-    is      => 'rw',
-    isa     => 'CodeRef',
-	predicate => 'has_readline_func',
-	clearer   => 'clear_readline_func',
+    is        => 'rw',
+    isa       => 'CodeRef',
+    predicate => 'has_readline_func',
+    clearer   => 'clear_readline_func',
 );
 
 with
@@ -31,8 +31,6 @@ with
   'HackaMol::Roles::NERFRole',
   'HackaMol::Roles::RcsbRole';
 
-
-
 sub pdbid_mol {
     my $self   = shift;
     my $pdbid  = shift || croak "Croak on passing pdbid, e.g. 2cba";
@@ -90,7 +88,7 @@ sub read_string_mol {
     my $format = shift or croak "must pass format: xyz, pdb, pdbqt, zmat, yaml";
 
     my @atoms = $self->read_string_atoms( $string, $format );
-    my $name = $format . ".mol";
+    my $name  = $format . ".mol";
     return ( HackaMol::Molecule->new( name => $name, atoms => [@atoms] ) );
 }
 
@@ -258,7 +256,7 @@ sub find_disulfide_bonds {
     my $self = shift;
 
     my @sulf = grep { $_->Z == 16 } @_;
-    my @ss = $self->find_bonds_brute(
+    my @ss   = $self->find_bonds_brute(
         bond_atoms => [@sulf],
         candidates => [@sulf],
         fudge      => 0.15,      # 0.45 is too large
@@ -333,7 +331,7 @@ sub group_rot {
         $iba => 1,
         $ibb => 1,
     };
-    my $root = $ibb;
+    my $root             = $ibb;
     my $rotation_indices = _qrotatable( $mol->atoms, $ibb, $init );
     delete( $rotation_indices->{$iba} );
     delete( $rotation_indices->{$ibb} );
@@ -553,9 +551,9 @@ sub _qrotatable {
 #Jacobi diagonalizer
 sub __diagonalize {
     my ( $onorm, $dnorm );
-    my ( $b, $dma, $q, $t, $c, $s );
+    my ( $b,     $dma,   $q, $t, $c, $s );
     my ( $atemp, $vtemp, $dtemp );
-    my ( $i, $j, $k, $l );
+    my ( $i,     $j,     $k, $l );
     my @a;
     my @v;
     my @d;
@@ -667,7 +665,7 @@ HackaMol - HackaMol: Object-Oriented Library for Molecular Hacking
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 DESCRIPTION
 
@@ -922,8 +920,45 @@ L<Protein Data Bank|http://pdb.org>
 
 L<VMD|http://www.ks.uiuc.edu/Research/vmd/>
 
+=item *
+
+L<Bio3D|http://thegrantlab.org/bio3d/>
+
+=item *
+
+L<MDAnalysis|https://www.mdanalysis.org/>
+
+=item *
+
+L<MDTraj|https://www.mdtraj.org/1.9.8.dev0/index.html>
+
 =back
 
+=head1 AUTHOR's PERSPECTIVE
+
+Over the years, I have found HackaMol most expeditious wrt testing out ideas 
+or whipping up setups and analyses for thousands of molecules each with 
+several thousand atoms. This is the realm of varied systems (lots of molecules
+often from the protein databank). For the analysis of MD simulations that hit 
+the next order of magnitude wrt numbers of atoms and frames, I use other tools (such as
+the python library, MDAnalysis). This is the realm where the system (molecular make-up)
+varies more slowly often with modeled solvent potentially with millions of simulated frames.  The future
+development of HackaMol will seek to remain in its lane and better serve that space.
+
+Perl is forever flexible and powerful; 
+HackaMol has the potential to be a broadly useful tool in this region of 
+molecular information, which is often dirty and not well-specified. Once 
+the object system is stable in the Perl core, I plan to rework HackaMol to 
+remove dependencies and improve performance. However, this tool will most
+likely never advance to the realm of analyzing molecular dynamics simulations. 
+For the analysis of MD simulations with explicit solvent, please look into 
+the python libraries MDAnalysis and MDTraj.  
+Bio3D, in R, is also very cool and able to nicely handle simulation data for 
+biological molecules stripped of solvent. In my view, Bio3D 
+seems to fill the space between HackaMol and MD simulations with explicit solvent. 
+These suggested tools are only the ones I am familiar with;
+I'm sure there are other very cool tools out there!  
+
 =head1 EXTENDS
 
 =over 4
