@@ -1,5 +1,5 @@
 package HackaMol::PeriodicTable;
-$HackaMol::PeriodicTable::VERSION = '0.051';
+$HackaMol::PeriodicTable::VERSION = '0.052';
 #ABSTRACT: package for period table data... needs to change
 use 5.008;
 require Exporter;
@@ -147,7 +147,7 @@ our %ATOMIC_MASSES = (
 our %ATOM_MULTIPLICITY = (
 
     # from jerry's thermo script
-    # see webelements.com .. thinking about term symbols and shit like that
+    # see webelements.com .. thinking about term symbols and stuff like that
     H  => 2,
     C  => 3,
     N  => 4,
@@ -518,17 +518,18 @@ our @VDW_RADII = (
 );
 
 our %KNOWN_NAMES;
-$KNOWN_NAMES{$_} = 'C' foreach qw(C CA CB CD CD1 CD2 CE CE1 
-                                 CE2 CE3 CG CG1 CG2 CH2 CZ CZ2 CZ3);
-$KNOWN_NAMES{$_} = 'H' foreach qw(H H1 H2 H3 H4 HA HA1 HA2 HB HB1 HB2 HB3 HD1 HD11 
-                                 HD12 HD13 HD2 HD21 HD22 HD23 HD3 HE 
-                                 HE1 HE2 HE21 HE22 HE3 HG HG1 HG11 HG12 
-                                 HG13 HG2 HG21 HG22 HG23 HH HH11 HH12 HH2 
-                                 HH21 HH22 HN HT1 HT2 HT3 HZ HZ1 HZ2 HZ3
-                                 DUM); 
-$KNOWN_NAMES{$_} = 'N' foreach qw(N ND1 ND2 NE NE1 NE2 NH1 NH2 NZ);
-$KNOWN_NAMES{$_} = 'O' foreach qw(O OD1 OD2 OE1 OE2 OG OG1 OH OT1 OT2 OH2 OXT);
-$KNOWN_NAMES{$_} = 'S' foreach qw(S SD SG);
+$KNOWN_NAMES{$_} = 'C' foreach qw(C CA CB CD CD1 CD2 CE CE1
+  CE2 CE3 CG CG1 CG2 CH2 CZ CZ2 CZ3);
+$KNOWN_NAMES{$_} = 'H'
+  foreach qw(H H1 H2 H3 H4 HA HA1 HA2 HB HB1 HB2 HB3 HD1 HD11
+  HD12 HD13 HD2 HD21 HD22 HD23 HD3 HE
+  HE1 HE2 HE21 HE22 HE3 HG HG1 HG11 HG12
+  HG13 HG2 HG21 HG22 HG23 HH HH11 HH12 HH2
+  HH21 HH22 HN HT1 HT2 HT3 HZ HZ1 HZ2 HZ3
+  DUM);
+$KNOWN_NAMES{$_} = 'N'  foreach qw(N ND1 ND2 NE NE1 NE2 NH1 NH2 NZ);
+$KNOWN_NAMES{$_} = 'O'  foreach qw(O OD1 OD2 OE1 OE2 OG OG1 OH OT1 OT2 OH2 OXT);
+$KNOWN_NAMES{$_} = 'S'  foreach qw(S SD SG);
 $KNOWN_NAMES{$_} = 'Cl' foreach qw(CLA);
 $KNOWN_NAMES{$_} = 'Na' foreach qw(SOD);
 $KNOWN_NAMES{$_} = 'K'  foreach qw(POT);
@@ -562,13 +563,12 @@ sub _element_name {
 #carp "$name doesn not exist in HackaMol::PeriodicTable, if common please add to KNOWN_NAMES";
         $dirt = 1;
         my $symbol = substr $name, 0, 1; #doesn't work if two letters for symbol
-        $symbol = 'C' if ($symbol eq 'A');
+        $symbol = 'C' if ( $symbol eq 'A' );
         return ( $symbol, $dirt );
     }
     return ( $KNOWN_NAMES{$name}, $dirt );
 }
 
-
 1;
 
 __END__
@@ -581,7 +581,7 @@ HackaMol::PeriodicTable - package for period table data... needs to change
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 EXTENDS
 
